@@ -1,4 +1,4 @@
-#' @title Bayesian correlation test.
+#' @title Bayes Factor for correlation test
 #' @name bf_corr_test
 #'
 #' @param x The column in `data` containing the explanatory variable to be
@@ -9,8 +9,8 @@
 #'   (e.g., `"y"`) or as a bare expression (e.g, `y`).
 #' @param bf.prior A number between `0.5` and `2` (default `0.707`), the prior
 #'   width to use in calculating Bayes factors.
-#' @inheritParams bf_expr
 #' @inheritParams bf_ttest
+#' @inheritDotParams bf_extractor -bf.object
 #'
 #' @importFrom BayesFactor correlationBF
 #' @importFrom dplyr pull
@@ -21,22 +21,24 @@
 #' @examples
 #' # for reproducibility
 #' set.seed(123)
+#' library(tidyBF)
 #'
-#' # to see results
+#' # to get dataframe
 #' bf_corr_test(
 #'   data = anscombe,
 #'   x = x1,
 #'   y = y4,
-#'   bf.prior = 1
+#'   bf.prior = 0.3,
+#'   output = "dataframe"
 #' )
 #'
-#' # to get caption
+#' # to get expression
 #' bf_corr_test(
 #'   data = anscombe,
 #'   x = x1,
 #'   y = y4,
 #'   bf.prior = 0.8,
-#'   output = "null"
+#'   output = "expression"
 #' )
 #' @export
 
@@ -45,9 +47,6 @@ bf_corr_test <- function(data,
                          x,
                          y,
                          bf.prior = 0.707,
-                         caption = NULL,
-                         output = "results",
-                         k = 2L,
                          ...) {
 
   # extracting results from Bayesian test and creating a dataframe
@@ -55,27 +54,9 @@ bf_corr_test <- function(data,
     BayesFactor::correlationBF(
       x = data %>% dplyr::pull({{ x }}),
       y = data %>% dplyr::pull({{ y }}),
-      rscale = bf.prior,
-      ...
+      rscale = bf.prior
     )
 
-  # prepare the Bayes Factor message
-  if (output != "results") {
-    bf_message <-
-      bf_expr(
-        bf.object = bf_object,
-        output = output,
-        k = k,
-        caption = caption,
-        ...
-      )
-  }
-
-  # return the text results or the dataframe with results
-  return(switch(
-    EXPR = output,
-    "results" = bf_extractor(bf_object),
-    bf_message,
-    ...
-  ))
+  # final return
+  bf_extractor(bf_object, ...)
 }
