@@ -1,4 +1,5 @@
 #' @title Bayes Factor for *t*-test
+#' @rdname bf_ttest
 #'
 #' @details If `y` is `NULL`, a one-sample *t*-test will be carried out,
 #'   otherwise a two-sample *t*-test will be carried out.
@@ -6,14 +7,17 @@
 #' @param x Either the grouping variable from the dataframe `data` if it's a
 #'   two-sample *t*-test or a numeric variable if it's a one-sample *t*-test.
 #' @inheritParams bf_corr_test
-#' @inheritParams bf_expr
 #' @inheritParams bf_oneway_anova
 #' @param test.value A number specifying the value of the null hypothesis
 #'   (Default: `0`).
+#' @inheritParams ipmisc::long_to_wide_converter
+#' @inheritDotParams bf_extractor -bf.object
 #'
 #' @importFrom BayesFactor ttestBF
-#' @importFrom rlang quo_is_null new_formula ensym enquo is_null
+#' @importFrom rlang quo_is_null new_formula ensym enquo exec !!!
 #' @importFrom stats na.omit
+#' @importFrom dplyr pull
+#' @importFrom ipmisc long_to_wide_converter
 #'
 #' @seealso \code{\link{bf_contingency_tab}}, \code{\link{bf_corr_test}},
 #' \code{\link{bf_oneway_anova}}
@@ -26,22 +30,35 @@
 #' set.seed(123)
 #' library(tidyBF)
 #'
-#' # to get dataframe
+#' # to get dataframe (between-subjects)
 #' bf_ttest(
 #'   data = mtcars,
 #'   x = am,
 #'   y = wt,
 #'   paired = FALSE,
-#'   bf.prior = 0.880
+#'   bf.prior = 0.880,
+#'   output = "dataframe"
+#' )
+#'
+#' # to get expression (within-subjects)
+#' bf_ttest(
+#'   data = dplyr::filter(bugs_long, condition %in% c("LDLF", "LDHF")),
+#'   x = condition,
+#'   y = desire,
+#'   subject.id = subject,
+#'   paired = TRUE,
+#'   bf.prior = 0.880,
+#'   output = "dataframe"
 #' )
 #'
 #' # ------------------- one-samples test -----------------------------------
 #'
-#' # to get dataframe
+#' # to get expression
 #' bf_ttest(
 #'   data = iris,
 #'   x = Sepal.Length,
-#'   test.value = 5.85
+#'   test.value = 5.85,
+#'   output = "expression"
 #' )
 #' @export
 
@@ -49,61 +66,16 @@
 bf_ttest <- function(data,
                      x,
                      y = NULL,
-                     test.value = 0,
+                     subject.id = NULL,
                      paired = FALSE,
+                     test.value = 0,
                      bf.prior = 0.707,
-                     caption = NULL,
-                     output = "results",
-                     k = 2L,
                      ...) {
 
   # make sure both quoted and unquoted arguments are allowed
   x <- rlang::ensym(x)
   y <- if (!rlang::quo_is_null(rlang::enquo(y))) rlang::ensym(y)
 
-  # -------------------------- two-sample tests ------------------------------
-
-  if (!rlang::quo_is_null(rlang::enquo(y))) {
-    # have a proper cleanup with NA removal
-    data %<>%
-      long_to_wide_converter(
-        data = .,
-        x = {{ x }},
-        y = {{ y }},
-        paired = paired,
-        spread = paired
-      )
-
-    # within-subjects design
-    if (isTRUE(paired)) {
-      # change names for convenience
-      colnames(data) <- c("rowid", "col1", "col2")
-
-      # extracting results from Bayesian test and creating a dataframe
-      bf_object <-
-        BayesFactor::ttestBF(
-          x = data$col1,
-          y = data$col2,
-          rscale = bf.prior,
-          paired = TRUE,
-          progress = FALSE
-        )
-    }
-
-    # between-subjects design
-    if (isFALSE(paired)) {
-      # extracting results from Bayesian test and creating a dataframe
-      bf_object <-
-        BayesFactor::ttestBF(
-          formula = rlang::new_formula({{ y }}, {{ x }}),
-          data = as.data.frame(data),
-          rscale = bf.prior,
-          paired = FALSE,
-          progress = FALSE
-        )
-    }
-  }
-
   # -------------------------- one-sample tests ------------------------------
 
   if (rlang::quo_is_null(rlang::enquo(y))) {
@@ -115,36 +87,36 @@ bf_ttest <- function(data,
       )
   }
 
-  # ============================ return ==================================
+  # -------------------------- two-sample tests ------------------------------
 
-  # prepare the Bayes factor message
-  if (output != "results") {
-    bf_message <-
-      bf_expr(
-        bf.object = bf_object,
-        output = output,
-        k = k,
-        caption = caption,
-        ...
+  if (!rlang::quo_is_null(rlang::enquo(y))) {
+    # have a proper cleanup with NA removal
+    data %<>%
+      ipmisc::long_to_wide_converter(
+        data = .,
+        x = {{ x }},
+        y = {{ y }},
+        subject.id = {{ subject.id }},
+        paired = paired,
+        spread = paired
+      )
+
+    # relevant arguments
+    if (isTRUE(paired)) bf.args <- list(x = data[[2]], y = data[[3]])
+    if (isFALSE(paired)) bf.args <- list(formula = rlang::new_formula({{ y }}, {{ x }}))
+
+    # creating a BayesFactor object
+    bf_object <-
+      rlang::exec(
+        .fn = BayesFactor::ttestBF,
+        rscale = bf.prior,
+        paired = paired,
+        progress = FALSE,
+        data = as.data.frame(data),
+        !!!bf.args
       )
   }
 
-  # return the text results or the dataframe with results
-  return(switch(
-    EXPR = output,
-    "results" = bf_extractor(bf_object),
-    bf_message
-  ))
+  # final return
+  bf_extractor(bf_object, ...)
 }
-
-#' @rdname bf_ttest
-#' @aliases bf_ttest
-#' @export
-
-bf_one_sample_ttest <- bf_ttest
-
-#' @rdname bf_ttest
-#' @aliases bf_ttest
-#' @export
-
-bf_two_sample_ttest <- bf_ttest
