@@ -1,18 +1,3 @@
-
-# ----------------------- ipmisc -----------------------------------
-
-#' @export
-#' @importFrom ipmisc specify_decimal_p
-ipmisc::specify_decimal_p
-
-#' @export
-#' @importFrom ipmisc signif_column
-ipmisc::signif_column
-
-#' @export
-#' @importFrom ipmisc long_to_wide_converter
-ipmisc::long_to_wide_converter
-
 # ----------------------- tidyverse -------------------------------------
 
 #' @export
